(handler handler opts)(handler-list ring-handler opts)(request-map base-request request)(safe-login-redirect request
{:slipway.handler/keys [ws-path] :or {ws-path "/chsk"}})With dual http/ws handlers it is possible that the websocket initialization request to {..}/chsk trigers a login redirection and we don't want to post-login http redirect to {..}/chsk. Dropping back to {..}/ is better
With dual http/ws handlers it is possible that the websocket initialization request to {..}/chsk trigers a login
redirection and we don't want to post-login http redirect to {..}/chsk. Dropping back to {..}/ is better(uri-without-chsk url ws-path)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |